@@ -4,6 +4,7 @@
 #include <QTreeView>
 #include <QListWidget>
 #include <phonon>
+#include <QSlider>
 #include <QPushButton>
 //#include <QMaemo5InformationBox>
 #include "mainwindow.h"
@@ -28,6 +29,7 @@
 #include "symfonieseekslider.h"
 #include "symfonielabelignoreevent.h"
 #include "symfonieqmenu.h"
+#include "symfoniespeeddialog.h"
 
 
 MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWidget *parent) :
@@ -38,6 +40,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
         fileTypesDialog(NULL),
         optionsDialog(NULL),
         volumeDialog(NULL),
+        speedDialog(NULL),
         player(player),
         equalizerWindow(new SymfonieEqualizerWindow(this)),
         currentOrientationMode(Qt::WA_Maemo5LandscapeOrientation),
@@ -195,6 +198,11 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     connect(goHomeAction, SIGNAL(triggered()), this, SLOT(goHomeSlot()));
 
 
+
+    this->showSpeedDialogAction = new QAction(QIcon::fromTheme("general_clock"), tr("Go Home"), ui->mainToolBar);
+    this->connect(showSpeedDialogAction, SIGNAL(triggered()), this, SLOT(showSpeedDialogSlot()));
+
+
     this->goToCurDir = new QAction(QIcon::fromTheme("imageviewer_rotate"), tr("Go to current directory"), ui->mainToolBar);
     connect(goToCurDir, SIGNAL(triggered()), this, SLOT(goToCurDirSlot()));
 
@@ -239,7 +247,11 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     QFileInfo info = QFileInfo(lastPlayedDir);
     if(info.exists()){
-        this->isResumePlayback = true;
+        if(SymfonieDb::getInstance()->getSetting("is_auto_resume_playback") != 0){
+            this->isResumePlayback = true;
+        }else{
+            this->isResumePlayback = false;
+        }
         this->getPlayer()->scanDir(lastPlayedDir);
     }else{
         this->goHomeSlot();
@@ -376,6 +388,9 @@ MainWindow::~MainWindow()
     delete switchOrientationAction;
     delete showInfoWindowAction;
     delete showToolBar2Action;
+
+    delete showSpeedDialogAction;
+
     delete goUpAction;
     delete goHomeAction;
     delete goToCurDir;
@@ -398,9 +413,30 @@ MainWindow::~MainWindow()
         delete this->volumeDialog;
     }
 
+    if(this->speedDialog != NULL){
+        delete this->speedDialog;
+    }
 
 }
 
+void MainWindow::showSpeedDialogSlot(){
+    if(this->speedDialog == NULL){
+        this->speedDialog = new SymfonieSpeedDialog(this);
+        this->connect(
+                speedDialog,
+                SIGNAL(speedChangedSignal(float)),
+                this,
+                SLOT(showSpeedDialogSliderChangedSlot(float))
+                );
+    }
+
+    this->speedDialog->exec();
+}
+
+void MainWindow::showSpeedDialogSliderChangedSlot(float value){
+    qDebug() << "Speed value from dialog: " << value;
+    this->getPlayer()->setSpeed(value);
+}
 
 
 
@@ -417,6 +453,8 @@ void MainWindow::setupToolBarButtonsLandscape(){
 
     this->ui->mainToolBar->addAction(showInfoWindowAction);
     this->ui->mainToolBar->addAction(this->showToolBar2Action);
+
+    this->ui->mainToolBar->addAction(this->showSpeedDialogAction);
     //this->ui->mainToolBar->addAction(this->toggleFullScreenAction);
 
     this->ui->mainToolBar2->hide();
@@ -427,15 +465,10 @@ void MainWindow::setupToolBarButtonsLandscape(){
 void MainWindow::setupToolBarButtonsPortrait(){
 
 
-
     this->ui->mainToolBar->clear();
     this->ui->mainToolBar2->clear();
 
 
-
-
-
-
     this->ui->mainToolBar2->addAction(prevAction);
     this->ui->mainToolBar2->addAction(playAction);
     this->ui->mainToolBar2->addAction(nextAction);
@@ -447,6 +480,8 @@ void MainWindow::setupToolBarButtonsPortrait(){
     this->ui->mainToolBar->addAction(this->goHomeAction);
     this->ui->mainToolBar->addAction(this->goUpAction);
     this->ui->mainToolBar->addAction(this->goToCurDir);
+    this->ui->mainToolBar->addAction(this->showSpeedDialogAction);
+
     // this->ui->mainToolBar->addAction(this->toggleFullScreenAction);
 
 
@@ -687,6 +722,7 @@ void MainWindow::saveState(){
 
     if(this->optionsDialog != NULL){
         SymfonieDb::getInstance()->saveSetting("is_show_main_toolbar", QVariant(this->optionsDialog->getOptionIsShowToolbar() ? 1:0));
+        SymfonieDb::getInstance()->saveSetting("is_auto_resume_playback", QVariant(this->optionsDialog->getOptionIsAutoResumePlayback() ? 1:0));
     }
     SymfonieDb::getInstance()->saveSetting("is_show_volume_slider", QVariant(this->ui->volumePanel->isVisible() ? 1:0));
 }
