@@ -23,6 +23,7 @@ class SymfonieVolumeDialog;
 class SymfonieFullScreenExitButton;
 class SymfonieVolumeSlider;
 class SymfonieSeekSlider;
+class SymfonieSpeedDialog;
 
 namespace Ui {
     class MainWindow;
@@ -62,6 +63,8 @@ private:
     SymfonieFileTypesDialog *fileTypesDialog;
     SymfonieOptionsDialog *optionsDialog;
     SymfonieVolumeDialog *volumeDialog;
+    SymfonieSpeedDialog *speedDialog;
+
 
     QAction *playAction;
     QAction *stopAction;
@@ -74,6 +77,7 @@ private:
     QAction *goHomeAction;
     QAction *goToCurDir;
     QAction *toggleFullScreenAction;
+    QAction *showSpeedDialogAction;
 
     QActionGroup *orientationGroup;
     QAction *orientationLandscape;
@@ -109,6 +113,9 @@ private:
    QString fileListWidgetItemFileToDelete;
 
 
+public Q_SLOTS:
+      void showSpeedDialogSliderChangedSlot(float);
+
 private Q_SLOTS:
     void itemActivatedSlot(QModelIndex);
     void mediaStateChangedSlot(Phonon::State newState, Phonon::State oldState);
@@ -128,6 +135,7 @@ private Q_SLOTS:
     void showAboutWindowSlot();
     void showTimerWindowSlot();
     void showVolumeDialogSlot();
+    void showSpeedDialogSlot();
     void volumeDialogClosedSlot();
     void updateTimerSlot(int time);
     void showEqualizerWindowSlot();
@@ -149,6 +157,7 @@ private Q_SLOTS:
     void deleteFileSlot();
 
 
+
 };
 
 #endif // MAINWINDOW_H
