@@ -14,6 +14,14 @@ SymfonieOptionsDialog::SymfonieOptionsDialog(MainWindow *parent) :
     }else{
         this->ui->isShowToolbar->setChecked(false);
     }
+
+
+    if(SymfonieDb::getInstance()->getSetting("is_auto_resume_playback", 1).toInt() == 1){
+        this->ui->isAutoResumePlayback->setChecked(true);
+    }else{
+        this->ui->isAutoResumePlayback->setChecked(false);
+    }
+
 }
 
 SymfonieOptionsDialog::~SymfonieOptionsDialog()
@@ -37,3 +45,7 @@ void SymfonieOptionsDialog::changeEvent(QEvent *e)
 bool SymfonieOptionsDialog::getOptionIsShowToolbar(){
     return this->ui->isShowToolbar->isChecked();
 }
+
+bool SymfonieOptionsDialog::getOptionIsAutoResumePlayback(){
+    return this->ui->isAutoResumePlayback->isChecked();
+}
